@@ -15,7 +15,6 @@ IRONIC_INSPECTOR_CMD_CONDUCTOR="$IRONIC_INSPECTOR_BIN_FILE_CONDUCTOR --config-fi
 IRONIC_INSPECTOR_DHCP_CONF_FILE=$IRONIC_INSPECTOR_CONF_DIR/dnsmasq.conf
 IRONIC_INSPECTOR_ROOTWRAP_CONF_FILE=$IRONIC_INSPECTOR_CONF_DIR/rootwrap.conf
 IRONIC_INSPECTOR_ADMIN_USER=${IRONIC_INSPECTOR_ADMIN_USER:-ironic-inspector}
-IRONIC_INSPECTOR_AUTH_CACHE_DIR=${IRONIC_INSPECTOR_AUTH_CACHE_DIR:-/var/cache/ironic-inspector}
 IRONIC_INSPECTOR_DHCP_FILTER=${IRONIC_INSPECTOR_DHCP_FILTER:-iptables}
 IRONIC_INSPECTOR_STANDALONE=${IRONIC_INSPECTOR_STANDALONE:-True}
 # Support entry points installation of console scripts
@@ -26,10 +25,10 @@ IRONIC_INSPECTOR_UWSGI_CONF=$IRONIC_INSPECTOR_CONF_DIR/ironic-inspector-uwsgi.in
 # explicitly unless otherwise set.
 IRONIC_INSPECTOR_ENFORCE_SCOPE=${IRONIC_INSPECTOR_ENFORCE_SCOPE:-${IRONIC_ENFORCE_SCOPE:-False}}
 # and then fallback to trueorfalse to put it into the standardized string format for the jobs.
-IRONIC_INSPECTOR_ENFORCE_SCOPE=$(trueorfalse False IRONIC_INSPECTOR_ENFORCE_SCOPE)
+IRONIC_INSPECTOR_ENFORCE_SCOPE=$(trueorfalse True IRONIC_INSPECTOR_ENFORCE_SCOPE)
 # Reset the input in the event the plugin is running separately from ironic's
 # devstack plugin.
-IRONIC_ENFORCE_SCOPE=$(trueorfalse False IRONIC_ENFORCE_SCOPE)
+IRONIC_ENFORCE_SCOPE=$(trueorfalse True IRONIC_ENFORCE_SCOPE)
 
 
 if [[ -n ${IRONIC_INSPECTOR_MANAGE_FIREWALL} ]] ; then
@@ -137,7 +136,7 @@ function inspector_iniset {
 function install_inspector {
     setup_develop $IRONIC_INSPECTOR_DIR
     # Check if things look okay
-    ironic-inspector-status upgrade check
+    $IRONIC_INSPECTOR_BIN_DIR/ironic-inspector-status upgrade check
     if [[ "$IRONIC_INSPECTOR_STANDALONE" == "False" ]]; then
         install_apache_wsgi
         # NOTE(rpittau) since devstack doesn't install test-requirements
@@ -337,7 +336,7 @@ function configure_inspector {
     inspector_iniset DEFAULT standalone $IRONIC_INSPECTOR_STANDALONE
     inspector_configure_auth_for ironic
     inspector_configure_auth_for service_catalog
-    configure_auth_token_middleware $IRONIC_INSPECTOR_CONF_FILE $IRONIC_INSPECTOR_ADMIN_USER $IRONIC_INSPECTOR_AUTH_CACHE_DIR/api
+    configure_keystone_authtoken_middleware $IRONIC_INSPECTOR_CONF_FILE $IRONIC_INSPECTOR_ADMIN_USER
 
     inspector_iniset DEFAULT listen_port $IRONIC_INSPECTOR_PORT
 
@@ -470,8 +469,6 @@ EOF
 }
 
 function prepare_environment {
-    create_ironic_inspector_cache_dir
-
     if [[ "$IRONIC_INSPECTOR_MANAGED_BOOT" == "False" ]]; then
         prepare_tftp
 
@@ -489,6 +486,8 @@ function prepare_environment {
             --dport 69 -j ACCEPT
         sudo iptables -I INPUT -i $IRONIC_INSPECTOR_INTERFACE -p tcp \
             --dport $IRONIC_INSPECTOR_PORT -j ACCEPT
+        sudo iptables -I INPUT -i $PUBLIC_BRIDGE -p tcp \
+            --dport $IRONIC_INSPECTOR_PORT -j ACCEPT
 
         if [[ "$IRONIC_INSPECTOR_STANDALONE" == "False" ]]; then
             sudo iptables -I INPUT -i $IRONIC_INSPECTOR_INTERFACE -p tcp --dport 80 -j ACCEPT
@@ -499,15 +498,6 @@ function prepare_environment {
     fi
 }
 
-# create_ironic_inspector_cache_dir() - Part of the prepare_environment() process
-function create_ironic_inspector_cache_dir {
-    # Create cache dir
-    mkdir_chown_stack $IRONIC_INSPECTOR_AUTH_CACHE_DIR/api
-    rm -f $IRONIC_INSPECTOR_AUTH_CACHE_DIR/api/*
-    mkdir_chown_stack $IRONIC_INSPECTOR_AUTH_CACHE_DIR/registry
-    rm -f $IRONIC_INSPECTOR_AUTH_CACHE_DIR/registry/*
-}
-
 function cleanup_inspector {
     if [[ "$IRONIC_IPXE_ENABLED" == "True" ]] ; then
         rm -f $IRONIC_HTTP_DIR/ironic-inspector.*
@@ -516,7 +506,6 @@ function cleanup_inspector {
         rm -f $IRONIC_TFTPBOOT_DIR/ironic-inspector.*
     fi
     sudo rm -f /etc/sudoers.d/ironic-inspector-rootwrap
-    sudo rm -rf $IRONIC_INSPECTOR_AUTH_CACHE_DIR
     sudo rm -rf "$IRONIC_INSPECTOR_RAMDISK_LOGDIR"
 
     if [[ "$IRONIC_INSPECTOR_STANDALONE" == "False" ]]; then
