@@ -14,10 +14,20 @@
 import socket
 
 from oslo_config import cfg
+from oslo_config import types as cfg_types
 
 from ironic_inspector.common.i18n import _
 
 
+class Octal(cfg_types.Integer):
+
+    def __call__(self, value):
+        if isinstance(value, int):
+            return value
+        else:
+            return int(str(value), 8)
+
+
 _OPTS = [
     cfg.StrOpt('listen_address',
                default='::',
@@ -25,14 +35,19 @@ _OPTS = [
     cfg.PortOpt('listen_port',
                 default=5050,
                 help=_('Port to listen on.')),
+    cfg.StrOpt('listen_unix_socket',
+               help=_('Unix socket to listen on. Disables listen_address and '
+                      'listen_port.')),
+    cfg.Opt('listen_unix_socket_mode', type=Octal(),
+            help=_('File mode (an octal number) of the unix socket to '
+                   'listen on. Ignored if listen_unix_socket is not set.')),
     cfg.StrOpt('host',
                default=socket.getfqdn(),
                sample_default='localhost',
                help=_('Name of this node. This can be an opaque identifier. '
                       'It is not necessarily a hostname, FQDN, or IP address. '
                       'However, the node name must be valid within '
-                      'an AMQP key, and if using ZeroMQ, a valid '
-                      'hostname, FQDN, or IP address.')),
+                      'an AMQP key.')),
     cfg.StrOpt('auth_strategy',
                default='keystone',
                choices=[('noauth', _('no authentication')),
@@ -80,7 +95,7 @@ _OPTS = [
                       'manage_boot==True).')),
     cfg.ListOpt('ipmi_address_fields',
                 default=['redfish_address', 'ilo_address', 'drac_host',
-                         'drac_address'],
+                         'drac_address', 'ibmc_address'],
                 help=_('Ironic driver_info fields that are equivalent '
                        'to ipmi_address.')),
     cfg.StrOpt('rootwrap_config',
