@@ -17,6 +17,7 @@ import random
 import re
 
 import flask
+import microversion_parse as mvp
 from oslo_utils import strutils
 from oslo_utils import uuidutils
 from werkzeug.middleware import proxy_fix
@@ -35,6 +36,7 @@ from ironic_inspector import process
 from ironic_inspector import rules
 from ironic_inspector import utils
 
+
 CONF = ironic_inspector.conf.CONF
 
 
@@ -78,8 +80,10 @@ def _init_middleware():
 
 def get_app():
     """Get the flask instance."""
-    _init_middleware()
-    return _app
+    with _app.app_context():
+        _init_middleware()
+        start_coordinator()
+        return _app
 
 
 # TODO(kaifeng) Extract rpc related code into a rpcapi module
@@ -116,11 +120,16 @@ def _get_version():
     ver = flask.request.headers.get(conf_opts.VERSION_HEADER,
                                     _DEFAULT_API_VERSION)
     try:
-        if ver.lower() == 'latest':
-            requested = CURRENT_API_VERSION
-        else:
-            requested = tuple(int(x) for x in ver.split('.'))
-    except (ValueError, TypeError):
+        requested = _DEFAULT_API_VERSION
+        if ver:
+            if ver.lower() == 'latest':
+                requested = CURRENT_API_VERSION
+            else:
+                requested = mvp.parse_version_string(ver)
+
+            if len(requested) != 2:
+                raise ValueError
+    except (ValueError, TypeError, AttributeError):
         return error_response(_('Malformed API version: expected string '
                                 'in form of X.Y or latest'), code=400)
     return requested
@@ -196,7 +205,6 @@ def convert_exceptions(func):
     return wrapper
 
 
-@_app.before_first_request
 def start_coordinator():
     """Create a coordinator instance for non-standalone case."""
     if not CONF.standalone:
@@ -280,7 +288,7 @@ def api(path, is_public_api=False, rule=None, verb_to_rule_map=None,
                           as public, with minimal access enforcement
     :param rule: API access policy rule to enforce.
                  If rule is None, the 'default' policy rule will be enforced,
-                 which is "deny all" if not overridden in policy confif file.
+                 which is "deny all" if not overridden in policy config file.
     :param verb_to_rule_map: if both rule and this are given,
                              defines mapping between http verbs (uppercase)
                              and strings to format the 'rule' string with
