@@ -17,19 +17,12 @@ import sys
 from oslo_concurrency import lockutils
 from oslo_config import cfg
 from oslo_log import versionutils
-from oslo_policy import opts
 from oslo_policy import policy
 
 CONF = cfg.CONF
 
 _ENFORCER = None
 
-# TODO(gmann): Remove setting the default value of config policy_file
-# once oslo_policy change the default value to 'policy.yaml'.
-# https://github.com/openstack/oslo.policy/blob/a626ad12fe5a3abd49d70e3e5b95589d279ab578/oslo_policy/opts.py#L49
-DEFAULT_POLICY_FILE = 'policy.yaml'
-opts.set_defaults(cfg.CONF, DEFAULT_POLICY_FILE)
-
 # Generic policy check string for system administrators. These are the people
 # who need the highest level of authorization to operate the deployment.
 # They're allowed to create, read, update, or delete any system-specific
@@ -264,7 +257,7 @@ def init_enforcer(policy_file=None, rules=None,
         default_rule=default_rule,
         use_conf=use_conf)
 
-    # NOTE(gmann): Explictly disable the warnings for policies
+    # NOTE(gmann): Explicitly disable the warnings for policies
     # changing their default check_str. With new RBAC policy
     # work, all the policy defaults have been changed and warning for
     # each policy started filling the logs limit for various tool.
