@@ -28,23 +28,21 @@ import eventlet
 import fixtures
 from oslo_config import cfg
 from oslo_config import fixture as config_fixture
-from oslo_db.sqlalchemy import enginefacade
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
-import pytz
 import requests
 
 from ironic_inspector.cmd import all as inspector_cmd
 from ironic_inspector.cmd import dbsync
 from ironic_inspector.common import ironic as ir_utils
-from ironic_inspector import db
+from ironic_inspector.db import api as db
 from ironic_inspector import introspection_state as istate
 from ironic_inspector import main
-from ironic_inspector import node_cache
 from ironic_inspector import rules
 from ironic_inspector.test import base
 from ironic_inspector.test.unit import test_rules
 
+
 eventlet.monkey_patch()
 
 CONF = """
@@ -106,11 +104,8 @@ def _query_string(*field_names):
 
 class Base(base.NodeTest):
     ROOT_URL = 'http://127.0.0.1:5050'
-    IS_FUNCTIONAL = True
 
-    # NOTE(TheJulia): Pre-configure the engine so we're compatible with
-    # oslo.db 12.1.0 for functional tests.
-    enginefacade.configure(sqlite_fk=False, __autocommit=True)
+    IS_FUNCTIONAL = True
 
     def setUp(self):
         super(Base, self).setUp()
@@ -151,7 +146,7 @@ class Base(base.NodeTest):
 
     def tearDown(self):
         super(Base, self).tearDown()
-        node_cache._delete_node(self.uuid)
+        db.delete_node(self.uuid)
 
     def call(self, method, endpoint, data=None, expect_error=None,
              api_version=None):
@@ -223,9 +218,9 @@ class Base(base.NodeTest):
         return {'uuid': self.uuid, 'finished': finished, 'error': error,
                 'state': state, 'finished_at': finished_at,
                 'started_at': started_at,
-                'links': [{u'href': u'%s/v1/introspection/%s' % (self.ROOT_URL,
-                                                                 self.uuid),
-                           u'rel': u'self'}]}
+                'links': [{'href': '%s/v1/introspection/%s' % (self.ROOT_URL,
+                                                               self.uuid),
+                           'rel': 'self'}]}
 
     def check_status(self, status, finished, state, error=None):
         self.assertEqual(
@@ -235,8 +230,10 @@ class Base(base.NodeTest):
                               error=error),
             status
         )
+        # CI Runs in UTC, local machines can fail on the use of the local
+        # timezone.
         curr_time = datetime.datetime.fromtimestamp(
-            time.time(), tz=pytz.timezone(time.tzname[0]))
+            time.time(), tz=datetime.timezone.utc)
         started_at = timeutils.parse_isotime(status['started_at'])
         self.assertLess(started_at, curr_time)
         if finished:
@@ -248,17 +245,18 @@ class Base(base.NodeTest):
 
     def db_row(self):
         """return database row matching self.uuid."""
-        return db.model_query(db.Node).get(self.uuid)
+        return db.get_node(self.uuid)
 
 
 class Test(Base):
     def test_bmc(self):
         self.call_introspect(self.uuid)
         eventlet.greenthread.sleep(DEFAULT_SLEEP)
+
         self.cli.set_node_power_state.assert_called_once_with(self.uuid,
                                                               'rebooting')
-
         status = self.call_get_status(self.uuid)
+
         self.check_status(status, finished=False, state=istate.States.waiting)
 
         res = self.call_continue(self.data)
@@ -386,11 +384,9 @@ class Test(Base):
 
         status = self.call_get_status(self.uuid)
         self.check_status(status, finished=True, state=istate.States.finished)
-
         # fetch all statuses and db nodes to assert pagination
         statuses = self.call_get_statuses().get('introspection')
-        nodes = db.model_query(db.Node).order_by(
-            db.Node.started_at.desc()).all()
+        nodes = db.get_nodes()
 
         # assert ordering
         self.assertEqual([node.uuid for node in nodes],
@@ -699,10 +695,8 @@ class Test(Base):
         # waiting -> processing is a strict state transition
         self.call_introspect(self.uuid)
         eventlet.greenthread.sleep(DEFAULT_SLEEP)
-        row = self.db_row()
-        row.state = istate.States.processing
-        with db.ensure_transaction() as session:
-            row.save(session)
+
+        db.update_node(self.uuid, state=istate.States.processing)
         self.call_continue(self.data, expect_error=400)
         status = self.call_get_status(self.uuid)
         self.check_status(status, finished=True, state=istate.States.error,
@@ -835,7 +829,6 @@ def mocked_server():
         except requests.ConnectionError:
             if i == 9:
                 raise
-            print('Service did not start yet')
             eventlet.greenthread.sleep(3)
         else:
             break
