@@ -401,7 +401,8 @@ class TestSync(DnsmasqTestBase):
         self.mock_ironic = mock.Mock()
         self.mock_utcnow = self.useFixture(
             fixtures.MockPatchObject(dnsmasq.timeutils, 'utcnow')).mock
-        self.timestamp_start = datetime.datetime.utcnow()
+        self.timestamp_start = datetime.datetime.now(
+            datetime.timezone.utc).replace(tzinfo=None)
         self.timestamp_end = (self.timestamp_start +
                               datetime.timedelta(seconds=42))
         self.mock_utcnow.side_effect = [self.timestamp_start,
@@ -484,6 +485,22 @@ class TestSync(DnsmasqTestBase):
                       self.timestamp_end - self.timestamp_start)
         ])
 
+    @mock.patch('time.sleep', lambda _x: None)
+    def test__sync_ironic_unavailable(self):
+        self.mock_ironic.ports.side_effect = os_exc.SDKException('boom')
+        self.driver._sync(self.mock_ironic)
+        self.mock__add_mac_to_allowlist.assert_not_called()
+        self.mock__add_mac_to_denylist.assert_not_called()
+
+        self.mock_ironic.ports.assert_called_with(fields=['address', 'extra'],
+                                                  limit=None)
+        self.mock_get_active_macs.assert_called_once_with(self.mock_ironic)
+        self.mock__get_deny_allow_lists.assert_not_called()
+        self.mock__configure_removedlist.assert_not_called()
+        self.mock_log.debug.assert_called_once_with('Syncing the driver')
+        self.mock_log.exception.assert_called_once_with(
+            "Could not list ironic ports, can not sync dnsmasq PXE filter")
+
 
 class Test_Execute(test_base.BaseTest):
     def setUp(self):
